# Copyright (c) 2023-2025 Arista Networks, Inc.
# Use of this source code is governed by the Apache License 2.0
# that can be found in the LICENSE file.
"""Syntax Error in file."""

# pylint: skip-file
typo  # type: ignore[name-defined] # noqa: B018
